@@ -29,16 +29,12 @@ from openstack_governance import members
 
 LOG = logging.getLogger(__name__)
 
-TC_SIZE = 13
+TC_SIZE = 11
 
 # For formal-vote votes, age in days that a change has to have existed
 # before it can be approved
 creation_age_threshold = datetime.timedelta(days=7)
 
-# For formal-vote votes, age in days since a change has reached a
-# the necessary amount of votes before it can be approved
-reached_votes_age_threshold = datetime.timedelta(days=3)
-
 
 def decode_json(raw):
     """Trap JSON decoding failures and provide more detailed errors
@@ -245,17 +241,10 @@ def get_one_status(change, delegates, tc_members):
                          creation_age_threshold.days)
             earliest = str(latest_created + creation_age_threshold)
         elif reached_necessary_votes:
-            # Wait at least reached_votes_age_threshold days
-            # after reaching necessary votes.
-            earliest = str(
-                reached_necessary_votes + reached_votes_age_threshold
-            )
-            since_necessary_votes = now.date() - reached_necessary_votes.date()
-            time_to_approve = since_necessary_votes > reached_votes_age_threshold
+            time_to_approve = True
         else:
             time_to_approve = False
-            earliest = "{} days after {} positive votes".format(
-                reached_votes_age_threshold.days, necessary_votes)
+            earliest = "after {} positive votes".format(necessary_votes)
 
         if votes_to_approve and time_to_approve:
             parts.append('YES')
@@ -361,13 +350,10 @@ def get_one_status(change, delegates, tc_members):
     elif topic in ('project-update', 'new-project'):
         # https://governance.openstack.org/tc/reference/house-rules.html#other-project-team-updates
 
-        # At least 7 days old.
-        earliest = str(latest_created + creation_age_threshold)
-
         if votes[-1] or code_reviews[-1]:
             can_approve = 'dissenting votes'
-        elif age <= datetime.timedelta(7):
-            can_approve = 'too soon'
+        elif votes[1] < 2:
+            can_approve = 'not enough reviews'
         else:
             can_approve = 'CAN APPROVE'
 
